==> mapguide-1.0.1.tar.gz: mapguide-1.0.1/Common/Stylization/RasterAdapter.h <==
//
//  Copyright (C) 2004-2006  Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "GeometryAdapter.h"

class RasterAdapter : public GeometryAdapter
{
public:

    RasterAdapter(LineBufferPool*);
    virtual ~RasterAdapter();

    virtual void Stylize(Renderer*                   renderer,
                         RS_FeatureReader*           features,
                         RS_FilterExecutor*          exec,
                         RS_Raster*                  raster,
                         MdfModel::GridColorStyle*   style,
                         const MdfModel::MdfString*  tooltip = NULL,
                         const MdfModel::MdfString*  url = NULL
                         );

    void DecodeRGBA(RS_InputStream* is, unsigned char* dst, int w, int h);

    void DecodeRGB(RS_InputStream* is, unsigned char* dst, int w, int h);

    void DecodeMapped(RS_InputStream* is, RS_InputStream* pal, unsigned char* dst, int w, int h);

    void DecodeBitonal(RS_InputStream* is, const RS_Color& fg, const RS_Color& bg, unsigned char* dst, int w, int h);

protected:

    RS_FilterExecutor* m_exec;
};

==> mapguide-1.2.0.tar.gz: mapguide-1.2.0/Common/Stylization/RasterAdapter.h <==
//
//  Copyright (C) 2004-2007 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef RASTERADAPTER_H
#define RASTERADAPTER_H

#include "GeometryAdapter.h"

class RasterAdapter : public GeometryAdapter
{
public:
    RasterAdapter(LineBufferPool*);
    virtual ~RasterAdapter();

    virtual void Stylize(Renderer*                   renderer,
                         RS_FeatureReader*           features,
                         RS_FilterExecutor*          exec,
                         RS_Raster*                  raster,
                         MdfModel::GridColorStyle*   style,
                         const MdfModel::MdfString*  tooltip = NULL,
                         const MdfModel::MdfString*  url = NULL,
                         RS_ElevationSettings*       elevSettings = NULL
                         );

    void DecodeRGBA(RS_InputStream* is, unsigned char* dst, int w, int h);
    void DecodeRGB(RS_InputStream* is, unsigned char* dst, int w, int h);
    void DecodeMapped(RS_InputStream* is, RS_InputStream* pal, unsigned char* dst, int w, int h);
    void DecodeBitonal(RS_InputStream* is, const RS_Color& fg, const RS_Color& bg, unsigned char* dst, int w, int h);

protected:
    RS_FilterExecutor* m_exec;
};

#endif
